#!/bin/sh

SHDIR="shbin10"
FILTERSCRIPTS="fxwpf inww6 outww6"

function err {
	echo -e "$*"
	exit 1
}

function cleanup {
	CDIR="$1/$SHDIR"
	# move the orig files back, remove links to filter.so
	for F in $FILTERSCRIPTS; do
		mv "$CDIR/${F}.orig" "$CDIR/$F" 2>/dev/null
		rm "$CDIR/${F}.so" 2>/dev/null
		done

	# remove filter.so
	rm "$CDIR/filter.so" 2> /dev/null
}
	
if [ -z "$1" ]; then
clear
cat <<OPENOFFICE


This is an unofficial patch for the Corel WordPerfect 8 filtrix filters.

This patch has been made by Open Office, an Amsterdam based company that
supports Linux on the desktop. For more information, see our website at
http://www.openoffice.nl/

We would be glad to help your company out with Linux.

To install this patch, please read the README file first.

OPENOFFICE

elif [ "$1" = "--deinstall" ]; then
	echo "removing the patch - or any files that were left during the installation."
	WPDIR="$2"
	[ -d "$WPDIR" ] || err "Sorry, $WPDIR is not a directory"
	[ -d "$WPDIR/$SHDIR" ] || err "Sorry, $WPDIR/$SHDIR does not exist. Is $WPDIR really your WordPerfect directory?"
	cleanup "$WPDIR"
	echo "Done. Please test your WordPerfect 8 installation."
else
	echo "Installing the patch."
	WPDIR="$1"
	[ -d "$WPDIR" ] || err "Sorry, $WPDIR is not a directory"
	[ -d "$WPDIR/$SHDIR" ] || err "Sorry, $WPDIR/$SHDIR does not exist. Is $WPDIR really your WordPerfect directory?"

	# see if this is a clean patch directory
	for F in $FILTERSCRIPTS "filter.so"; do
		[ -f "$F" ] || err "Sorry, the patch file $F does not exist. Start this script from the install directory."
		done

	# see if the filters exist.
	for F in $FILTERSCRIPTS; do
		[ -f "$WPDIR/$SHDIR/$F" ] || err "Sorry, $WPDIR/$SHDIR/$F does not exist. Cannot find the filters to patch."
		done

	# see if the patch has been applied already
	for F in $FILTERSCRIPTS; do
		[ -f "$WPDIR/$SHDIR/${F}.orig" ] && err "Sorry, $WPDIR/$SHDIR/${F}.orig exists.\nThis means the patch has been installed already.\n\nYou can only install this patch once.\nTo de-install, start\n$0 --deinstall $WPDIR"
		done

	# copy the filter lib
	cp filter.so "$WPDIR/$SHDIR" || err "Sorry, could not copy the filter.so patchfile."

	for F in $FILTERSCRIPTS; do
		cp "$WPDIR/$SHDIR/$F" "$WPDIR/$SHDIR/${F}.orig" || (cleanup "$WPDIR"; err "Sorry, could not copy $WPDIR/$SHDIR/$F to $WPDIR/$SHDIR/${F}")
		done

	for F in $FILTERSCRIPTS; do
		ln -fs filter.so "$WPDIR/$SHDIR/${F}.so" || (cleanup "$WPDIR"; err "Sorry, could not create link $WPDIR/$SHDIR/${F}.so")
		done

	# now for the final action: copy the filterscripts to their new destination
	for F in $FILTERSCRIPTS; do
		cp "$F" "$WPDIR/$SHDIR/$F" || (cleanup "$WPDIR"; err "Sorry, could not copy $F to $WPDIR/$SHDIR/${F}")
		done

	echo "Ready. Please test your WordPerfect 8 installation and the filters."
fi
